/* 
Query and display NVIDIA VDPAU capabilities, a la glxinfo 
version 0.0.2

Copyright (c) 2008 Wladimir J. van der Laan

Permission is hereby granted, free of charge, to any person
obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without
restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following
conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.
*/
/// TODO
/// - possible bug, querying VDP_CHROMA_TYPE_444 returns an error
///  (VDP_STATUS_INVALID_CHROMA_TYPE) is this NVIDIA or us?
/// - parse display/screen from command line
/// - list color table formats for queryOutputSurface

#include <stdlib.h>
#include <stdio.h>
#include <vdpau/vdpau.h>
#include <vdpau/vdpau_x11.h>

#include "VDPDeviceImpl.h"

bool queryDecoderCaps(VDPDeviceImpl *device)
{
    VdpStatus rv;
        VdpBool is_supported = false;
        uint32_t max_level, max_macroblocks, max_width, max_height;

        rv = device->DecoderQueryCapabilities(device->device, VDP_DECODER_PROFILE_MPEG4_PART2_SP, 
            &is_supported, &max_level, &max_macroblocks, &max_width, &max_height);
        if(rv == VDP_STATUS_OK && is_supported)
	{
	return(true);
	}else
	{
	return(false);
	}
}


int main(int argc, char **argv)
{
    /* Create an X Display */
    Display *display;
    int screen;
    char *display_name = XDisplayName(NULL);
    if ((display=XOpenDisplay(display_name)) == NULL)
    {
        fprintf(stderr,"vdpauinfo: cannot connect to X server %s\n",
              XDisplayName(display_name));
        exit(-1);
    }
    screen = DefaultScreen(display);
    
    /* Create device */
    VdpDevice device;
    VdpGetProcAddress *get_proc_address;
    VdpStatus rv;
    rv = vdp_device_create_x11(display, screen, &device, &get_proc_address);
    if(rv != VDP_STATUS_OK)
    {
        fprintf(stderr, "Error creating VDPAU device: %i\n", rv); /* cannot use GetErrorString here */
        exit(-1);
    }    
    
    VDPDeviceImpl *impl = new VDPDeviceImpl(device, get_proc_address);
    
    if(queryDecoderCaps(impl)==true)
    {
	printf("ffodivxvdpau");
    }

    printf("\n");
}
